summaryrefslogtreecommitdiff
path: root/utils/lib_install.sh
diff options
context:
space:
mode:
authorMarkus Heiser <markus.heiser@darmarit.de>2022-05-27 18:43:14 +0200
committerMarkus Heiser <markus.heiser@darmarit.de>2022-07-30 13:39:35 +0200
commit782f73540e2d383ea122716507ccd9582918ab51 (patch)
tree2cca6c47e63cdf383883a2a47ac8329e629bb40d /utils/lib_install.sh
parent81bba4486916dbca4467a7e8c8b839a7c55c2a09 (diff)
[utils/searxng.sh] implement new script to install SearXNG
Signed-off-by: Markus Heiser <markus.heiser@darmarit.de>
Diffstat (limited to 'utils/lib_install.sh')
-rwxr-xr-xutils/lib_install.sh7
1 files changed, 4 insertions, 3 deletions
diff --git a/utils/lib_install.sh b/utils/lib_install.sh
index 04bec5d9a..44734e165 100755
--- a/utils/lib_install.sh
+++ b/utils/lib_install.sh
@@ -126,7 +126,7 @@ install_log_searx_instance() {
if in_container; then
# SearXNG is listening on 127.0.0.1 and not available from outside container
# in containers the service is listening on 0.0.0.0 (see lxc-searx.env)
echo -e "---- container setup"
echo -e " ${_BBlack}HINT:${_creset} SearXNG only listen on loopback device" \
"${_BBlack}inside${_creset} the container."
@@ -198,10 +198,11 @@ if in_container; then
# hint: Linux containers do not have DNS entries, lets use IPs
SEARXNG_URL="http://$(primary_ip)"
fi
+# shellcheck disable=SC2034
PUBLIC_URL="${SEARXNG_URL}"
source_dot_config
-# shellcheck source=utils/lxc-searx.env
-source "${REPO_ROOT}/utils/lxc-searx.env"
+# shellcheck source=utils/lxc-searxng.env
+source "${REPO_ROOT}/utils/lxc-searxng.env"
in_container && lxc_set_suite_env
@@ -126,7 +126,7 @@ install_log_searx_instance() {
if in_container; then
# SearXNG is listening on 127.0.0.1 and not available from outside container
- # in containers the service is listening on 0.0.0.0 (see lxc-searx.env)
+ # in containers the service is listening on 0.0.0.0 (see lxc-searxng.env)
echo -e "---- container setup"
echo -e " ${_BBlack}HINT:${_creset} SearXNG only listen on loopback device" \